@@ -4,6 +4,7 @@ Provides the top level flask application configuration.
 
 import sentry_sdk
 from flask import Flask
+from flask_cors import CORS
 from flask_dance.contrib.azure import make_azure_blueprint
 from sentry_sdk.integrations.flask import FlaskIntegration
 from sentry_sdk.integrations.sqlalchemy import SqlalchemyIntegration
@@ -27,13 +28,13 @@ def create_app() -> Flask:
         log.debug("Initialising Sentry SDK.")
         sentry_sdk.init(  # pylint: disable=abstract-class-instantiated
             dsn=settings.sentry_dsn,
-            environment=settings.environment,
             integrations=[FlaskIntegration(), SqlalchemyIntegration()],
         )
 
     log.debug("Initializing app.")
 
     app = Flask(__name__)
+    CORS(app)
     app.wsgi_app = ProxyFix(  # type: ignore
         app.wsgi_app,
         x_proto=int(settings.use_x_forwarded_proto),
@@ -41,7 +42,6 @@ def create_app() -> Flask:
     )
 
     app.config.update(
-        ENV=settings.environment,
         SECRET_KEY=settings.secret_key,
         SQLALCHEMY_DATABASE_URI=settings.postgres_dsn,
         SQLALCHEMY_TRACK_MODIFICATIONS=False,
